/* ver.B.b16.03(BLAZE) */


#include "version.h"


VERSION machine_code_version = {
	"AP.code",
	"cosmos",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b16.03(BLAZE)",
	2007,5,31,
	0,
	"GLOBALBASE client ",
};

